import path from "path";
import { fileURLToPath } from 'url';

const __filename = fileURLToPath(import.meta.url);
const __dirname = path.dirname(__filename);

export default
{
	mode: "development",
	devtool: "eval-cheap-module-source-map",
	context: __dirname,

	entry: {
		three: './src/main-three.ts'
	},
	output: {
		filename: '[name].bundle.js',
		path: path.resolve(__dirname,"./public_html/js/")
	},
	resolve: {
		modules: ['src','node_modules','.yarn'],
		fallback: { 
			fs: false,
			path: false
		}
	},
	module: {
		rules:[
		{
			test: /\.tsx?$/,
			use: 'ts-loader',
			exclude: [/node_modules/,/\.yarn/],
		},
		{
			test: /\.wasm$/,
			type: 'asset/resource'
		}]
	},
	optimization: {
		moduleIds: "named",
		chunkIds: "named",
		splitChunks: 
		{
			cacheGroups: 
			{
				commons: 
				{
					test: /[\\/]node_modules[\\/](?!@mantisvision[\\/].+[\\/])/,
					name: 'vendors',
					filename: "vendors.bundle.js",
					chunks: 'all'
				}
			}
		}
	}
};
